summaryrefslogtreecommitdiffstats
path: root/kmymoney2/converter
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2025-01-22 17:47:33 +0900
committerMichele Calgaro <[email protected]>2025-01-22 17:47:33 +0900
commitb3ce2906415b23672e2926cfaf0c23306296dbe0 (patch)
treee3c28a799b7da40728a35def1e74a8581d7be084 /kmymoney2/converter
parentc26a85580816a46920b60a7c746345c64406bb19 (diff)
downloadkmymoney-master.tar.gz
kmymoney-master.zip
Use tdeAppHEADmaster
Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'kmymoney2/converter')
-rw-r--r--kmymoney2/converter/mymoneyqifreader.cpp2
-rw-r--r--kmymoney2/converter/webpricequote.cpp10
2 files changed, 6 insertions, 6 deletions
diff --git a/kmymoney2/converter/mymoneyqifreader.cpp b/kmymoney2/converter/mymoneyqifreader.cpp
index c09aa44..bda6612 100644
--- a/kmymoney2/converter/mymoneyqifreader.cpp
+++ b/kmymoney2/converter/mymoneyqifreader.cpp
@@ -513,7 +513,7 @@ bool MyMoneyQifReader::finishImport(void)
dlg.progressBar()->setTextEnabled(true);
dlg.setAllowCancel(true);
dlg.show();
- kapp->processEvents();
+ tdeApp->processEvents();
MyMoneyFile* file = MyMoneyFile::instance();
TQValueList<MyMoneyTransaction>::iterator it = m_transactionCache.begin();
MyMoneyFileTransaction ft;
diff --git a/kmymoney2/converter/webpricequote.cpp b/kmymoney2/converter/webpricequote.cpp
index d057b49..be7e07c 100644
--- a/kmymoney2/converter/webpricequote.cpp
+++ b/kmymoney2/converter/webpricequote.cpp
@@ -85,7 +85,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
// if we're running normally, with a UI, we can just get these the normal way,
// from the config file
- if ( kapp )
+ if ( tdeApp )
{
TQString sourcename = _sourcename;
if ( sourcename.isEmpty() )
@@ -96,7 +96,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
else
emit error(TQString("Source <%1> does not exist.").arg(sourcename));
}
// otherwise, if we have no kapp, we have no config. so we just get them from
// the defaults
else
{
@@ -132,7 +132,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
// Note that a 'non-interactive' session right now means only the test
// cases. Although in the future if KMM gains a non-UI mode, this would
// still be useful
- if ( ! kapp && ! url.isLocalFile() )
+ if ( ! tdeApp && ! url.isLocalFile() )
url = KURL::fromPathOrURL("/usr/bin/wget -O - " + url.prettyURL());
if ( url.isLocalFile() )
@@ -146,7 +146,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
// if we're running non-interactive, we'll need to block.
// otherwise, just let us know when it's done.
TDEProcess::RunMode mode = TDEProcess::NotifyOnExit;
- if ( ! kapp )
+ if ( ! tdeApp )
mode = TDEProcess::Block;
if(m_filter.start(mode, TDEProcess::All))
@@ -284,7 +284,7 @@ bool WebPriceQuote::launchFinanceQuote ( const TQString& _symbol, const TQString
// if we're running non-interactive, we'll need to block.
// otherwise, just let us know when it's done.
TDEProcess::RunMode mode = TDEProcess::NotifyOnExit;
- if ( ! kapp )
+ if ( ! tdeApp )
mode = TDEProcess::Block;
if(m_filter.start(mode, TDEProcess::All))
@@ -96,7 +96,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
emit error(TQString("Source <%1> does not exist.").arg(sourcename));
}
- // otherwise, if we have no kapp, we have no config. so we just get them from
+ // otherwise, if we have no tdeApp, we have no config. so we just get them from
// the defaults
else